# latest earthquake in Indonesia
this is an earthquake package from the Meteorological, Climatological, and Geophysical Agency (BMKG) information center in Indonesia

#About
This Package will scrape form [BMKG](https://www.bmkg.go.id/) to get latest eartquake in Indonesia.

Using Library BeautifulSoup4 and Requests, to produce output in the form of JSON that is ready to be used in web or mobile apps